@@ -22,7 +22,6 @@ def main(hub, args):
 
     #newest_version = hub.remoteindex.getnewestversion(
 
-    hub.require_valid_current_with_index()
     setup = hub.cwd.join("setup.py")
     if not setup.check():
         hub.fatal("no setup.py found in", hub.cwd)
@@ -32,6 +31,9 @@ def main(hub, args):
     hub.info("hg-exported project to", exported)
 
     #set_new_version(hub, args, exported)
+    if not hub.current.pypisubmit:
+        hub.fatal("no pypisubmit endpoint available for: %s" %
+                  hub.current.index)
     if not args.onlydocs:
         exported.setup_register()
         exported.setup_upload()
@@ -178,13 +180,16 @@ class Exported:
         else:
             hub.fatal("release registration failed\n", out)
 
+    def _getuserpassword(self):
+        auth = self.hub.http.auth
+        if auth:
+            return auth
+        return "_test", "test"
+
     def setup_upload(self):
         current = self.hub.current
         cwd = self.rootpath
-        user, password = self.hub.http.auth
-        if not user:
-            self.hub.fatal("need to be logged in to perform this action")
-
+        user, password = self._getuserpassword()
         formats = [x.strip() for x in self.hub.args.formats.split(",")]
         for format in formats:
             if not format:
@@ -214,9 +219,7 @@ class Exported:
     def setup_upload_docs(self):
         current = self.hub.current
         cwd = self.rootpath
-        user, password = self.hub.http.auth
-        if not user:
-            self.hub.fatal("need to be logged in to perform this action")
+        user, password = self._getuserpassword()
         if self.hub.args.dryrun:
             self.hub.info("would upload docs from", cwd, "to",
                           current.pypisubmit)
