@@ -38,7 +38,7 @@ class TestCheckout:
         try:
             runproc("hg init")
             runproc("hg add file setup.py")
-            runproc("hg commit -m message")
+            runproc("hg commit --config ui.username=whatever -m message")
         finally:
             old.chdir()
         return repo
@@ -124,6 +124,14 @@ def test_readpypirc(monkeypatch, tmpdir):
     assert current["realm"] == "pypi"
     assert sys.argv == ["setup.py", "register", "1"]
 
+def test_setuppy_execution_namespace(monkeypatch, tmpdir):
+    from devpi.upload.setuppy import run_setuppy
+    def mockexecfile(filename, global_ns, local_ns=None):
+        assert global_ns["__file__"] == os.path.join(str(tmpdir), "setup.py")
+    monkeypatch.setattr(py.builtin.builtins, 'execfile', mockexecfile)
+    tmpdir.chdir()
+    run_setuppy()
+
 class TestUploadFunctional:
     def test_dryrun_all(self, initproj, devpi):
         initproj("hello-1.0", {"doc": {
@@ -136,3 +144,10 @@ class TestUploadFunctional:
         devpi("upload", "--formats", "sdist.tbz")
         devpi("upload", "--formats", "sdist.tgz,bdist_dumb")
 
+        # logoff then upload
+        devpi("logoff")
+        devpi("upload", "--dryrun", code=404)
+
+        # go to other index
+        devpi("use", "root/pypi")
+        devpi("upload", "--dryrun", code=404)
